<?php

declare(strict_types=1);

namespace App\Controller\OgBoot;

use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

#[Route('/og-boot')]
#[AsController]
class OgBootController extends AbstractController
{
    /**
     * @throws TransportExceptionInterface
     * @throws ServerExceptionInterface
     * @throws RedirectionExceptionInterface
     * @throws ClientExceptionInterface
     */
    #[Route('/status', name: 'ogboot_status',  methods: ['GET'])]
    public function status(HttpClientInterface $httpClient): JsonResponse
    {
        try {
            $response = $httpClient->request('GET', 'https://api.example.com/ogboot/v1/status', [
                'headers' => [
                    'accept' => 'application/json',
                ],
            ]);
        } catch (TransportExceptionInterface $e) {
            return new JsonResponse( data: 'An error occurred', status: Response::HTTP_INTERNAL_SERVER_ERROR);
        }

        $data = json_decode($response->getContent(), true);

        return new JsonResponse( data: $data, status: Response::HTTP_OK);
    }


    /**
     * @throws TransportExceptionInterface
     * @throws ServerExceptionInterface
     * @throws RedirectionExceptionInterface
     * @throws ClientExceptionInterface
     */
    #[Route('/status', name: 'ogboot_config',  methods: ['GET'])]
    public function config(HttpClientInterface $httpClient): JsonResponse
    {
        try {
            $response = $httpClient->request('GET', 'https://api.example.com/ogboot/v1/config', [
                'headers' => [
                    'accept' => 'application/json',
                ],
            ]);
        } catch (TransportExceptionInterface $e) {
            return new JsonResponse( data: 'An error occurred', status: Response::HTTP_INTERNAL_SERVER_ERROR);
        }

        $data = json_decode($response->getContent(), true);

        return new JsonResponse( data: $data, status: Response::HTTP_OK);
    }
}
